copyWith method
Returns a new instance by overriding the values passed as arguments
Implementation
FileSystemPaths copyWith({String? inputPath}) =>
FileSystemPaths(inputPath: inputPath ?? this.inputPath);
Returns a new instance by overriding the values passed as arguments
FileSystemPaths copyWith({String? inputPath}) =>
FileSystemPaths(inputPath: inputPath ?? this.inputPath);