HandleTables class

Simply a wrapper around a mutable mapping from ResourceType to HandleTable

TODO(generator): While this Python code performs a dynamic hash-table lookup on each handle table access, as we'll see below, the rt parameter is always statically known such that a normal implementation can statically enumerate all HandleTable objects at compile time and then route the calls to add, get and transfer_or_drop to the correct HandleTable at the callsite. The net result is that each component instance will contain one handle table per resource type used by the component, with each compiled adapter function accessing the correct handle table as-if it were a global variable.

Constructors

HandleTables()

Properties

hashCode int
The hash code for this object.
no setterinherited
rt_to_table Map<ResourceType, HandleTable>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(ResourceType rt, Handle h) int
get(ResourceType rt, int i) Handle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(ResourceType rt, int i) Handle
table(ResourceType rt) HandleTable
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited