ResultException<O, E> class

An exception that wraps inner, a Result

Implemented types

Constructors

ResultException(Result<O, E> inner)
An exception that wraps inner, a Result
const

Properties

hashCode int
The hash code for this object.
no setterinherited
inner Result<O, E>
The result that caused the exception
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited