build abstract method
Builds the instance asynchronously. May throw if some required imports where not supplied.
Implementation
Future<WasmInstance> build();
Builds the instance asynchronously. May throw if some required imports where not supplied.
Future<WasmInstance> build();